require "spec_helper"

describe PaceConverter do  
  describe "#from_mins_mile" do
    it "returns 0 meters/second for nil mins nil secs" do
      expect(PaceConverter.new.from_mins_mile(nil, nil)).to eql(0.0)
    end
    
    it "returns 0 meters/second for 0 mins 0 secs" do
      expect(PaceConverter.new.from_mins_mile(0, 0)).to eql(0.0)
    end
    
    it "returns 2.555 meters/second for 10 mins 30 secs" do
      expect(PaceConverter.new.from_mins_mile(10, 30)).to eql(2.555)
    end

    it "returns 2.555 meters/second for 10.5 mins 30.9 secs as only integer are accepted" do
      expect(PaceConverter.new.from_mins_mile(10.5, 30.9)).to eql(2.555)
    end

    it "returns 2.555 meters/second for -10 mins -30 secs as only positive value are accepted" do
      expect(PaceConverter.new.from_mins_mile(-10, -30)).to eql(2.555)
    end
  end

  describe "#from_miles_hour" do
    it "returns 0 meters/second for nil miles" do
      expect(PaceConverter.new.from_miles_hour(nil)).to eql(0.0)
    end
    
    it "returns 0 meters/second for 0 miles" do
      expect(PaceConverter.new.from_miles_hour(0)).to eql(0.0)
    end
    
    it "returns 4.470 meters/second for 10 miles" do
      expect(PaceConverter.new.from_miles_hour(10)).to eql(4.470)
    end

    it "returns 4.694 meters/second for 10.5 miles" do
      expect(PaceConverter.new.from_miles_hour(10.5)).to eql(4.694)
    end

    it "returns 4.470 seconds for -10 miles as only positive value are accepted" do
      expect(PaceConverter.new.from_miles_hour(-10)).to eql(4.470)
    end
  end
  
  describe "#from_mins_km" do
    it "returns 0 meters/second for nil mins nil secs" do
      expect(PaceConverter.new.from_mins_km(nil, nil)).to eql(0.0)
    end
    
    it "returns 0 meters/second for 0 mins 0 secs" do
      expect(PaceConverter.new.from_mins_km(0, 0)).to eql(0.0)
    end
    
    it "returns 1.587 meters/second for 10 mins 30 secs" do
      expect(PaceConverter.new.from_mins_km(10, 30)).to eql(1.587)
    end

    it "returns 1.587 meters/second for 10.5 mins 30.9 secs as only integer are accepted" do
      expect(PaceConverter.new.from_mins_km(10.5, 30.9)).to eql(1.587)
    end

    it "returns 1.587 meters/second for -10 mins -30 secs as only positive value are accepted" do
      expect(PaceConverter.new.from_mins_km(-10, -30)).to eql(1.587)
    end
  end
  
  describe "#from_kms_hour" do
    it "returns 0.0 meters/second for nil kilometers" do
      expect(PaceConverter.new.from_kms_hour(nil)).to eql(0.0)
    end
    
    it "returns 0.0 meters/second for 0 kilometers" do
      expect(PaceConverter.new.from_kms_hour(0)).to eql(0.0)
    end
    
    it "returns 2.778 meters/second for 10 kilometers" do
      expect(PaceConverter.new.from_kms_hour(10)).to eql(2.778)
    end

    it "returns 2.917 meters/second for 10.5 kilometers" do
      expect(PaceConverter.new.from_kms_hour(10.5)).to eql(2.917)
    end

    it "returns 2.778 meters/second for -10 kilometers as only positive value are accepted" do
      expect(PaceConverter.new.from_kms_hour(-10)).to eql(2.778)
    end
  end

  describe "revert convertion of 4 m/s" do
    before(:each) do
      @pace_converter = PaceConverter.new
      @pace_converter.from_meters_sec(4)
    end
    
    it "return 6.706 mins/mile" do
      expect(@pace_converter.to_mins_mile).to eq(6.706)
    end
   
    it "return 8.948 miles/hour" do
      expect(@pace_converter.to_miles_hour).to eq(8.948)
    end

    it "return 4.167 mins/km" do
      expect(@pace_converter.to_mins_km).to eq(4.167)
    end

    it "return 14.4 kms/hour" do
      expect(@pace_converter.to_kms_hour).to eq(14.4)
    end

    it "return 4 meters/sec" do
      expect(@pace_converter.to_meters_sec).to eq(4)
    end
    
  end

  describe "revert convertion of 3.2 m/s" do
    before(:each) do
      @pace_converter = PaceConverter.new
      @pace_converter.from_meters_sec(3.2)
    end
    
    it "return 8.382 mins/mile" do
      expect(@pace_converter.to_mins_mile).to eq(8.382)
    end
    
    it "return 7.158 miles/hour" do
      expect(@pace_converter.to_miles_hour).to eq(7.158)
    end

    it "return 5.208 mins/km" do
      expect(@pace_converter.to_mins_km).to eq(5.208)
    end

    it "return 11.52 kms/hour" do
      expect(@pace_converter.to_kms_hour).to eq(11.52)
    end

    it "return 3.2  meters/sec" do
      expect(@pace_converter.to_meters_sec).to eq(3.2)
    end
    
  end

  
end
